summaryrefslogtreecommitdiffstats
path: root/src/svnfrontend/propertiesdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/svnfrontend/propertiesdlg.cpp')
-rw-r--r--src/svnfrontend/propertiesdlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/svnfrontend/propertiesdlg.cpp b/src/svnfrontend/propertiesdlg.cpp
index 7bef811..4829a8a 100644
--- a/src/svnfrontend/propertiesdlg.cpp
+++ b/src/svnfrontend/propertiesdlg.cpp
@@ -38,15 +38,15 @@
#include <kdebug.h>
/*
* Constructs a PropertiesDlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-PropertiesDlg::PropertiesDlg(SvnItem*which, svn::Client*aClient, const svn::Revision&aRev, TQWidget* tqparent, const char* name, bool modal)
+PropertiesDlg::PropertiesDlg(SvnItem*which, svn::Client*aClient, const svn::Revision&aRev, TQWidget* parent, const char* name, bool modal)
:
- KDialogBase(tqparent,name,modal,i18n("Modify properties"),Ok|Cancel/*|Help|User1|User2*/, Ok,
+ KDialogBase(parent,name,modal,i18n("Modify properties"),Ok|Cancel/*|Help|User1|User2*/, Ok,
true/*, KStdGuiItem::add(),KStdGuiItem::remove() */),
m_Item(which),m_changed(false),
m_Client(aClient),m_Rev(aRev)
@@ -38,15 +38,15 @@
#include <kdebug.h>
/*
- * Constructs a PropertiesDlg as a child of 'tqparent', with the
+ * Constructs a PropertiesDlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*